#######################
Comedi data acquisition
#######################

The Comedi libraries provide a convenient method for interacting with data acquisition cards, but are restricted to Linux compatible operating systems.

.. automodule:: pymeasure.instruments.comedi
   :members:
